#ifndef SCALAR_FUNC_H_
#define SCALAR_FUNC_H_

#include <functions/Function.h>

/** 
 * ScalarFunc provides a base class for scalar-valued functions
 * @short Scalar functions
 */
class ScalarFunc : public Function
{
public:
  ScalarFunc (std::string const &name, unsigned int npar);
  /** 
   * Implementation of the virtual function Function::evaluate, which
   * uses the simplified version of evaluate below
   */
  void evaluate (SArray & value,
		 std::vector <SArray const *> const &args) const;
  /**
   * Scalar functions only need to implement this version of the evaluate
   * function, which returns a double.
   */
  virtual double evaluate (std::vector <SArray const *> const &args) const =
    0;
  /**
   * Returns Index(1) since the result of a scalar function should
   * always be scalar
   */
  Index dim (std::vector <SArray const *> const &args) const;
};

#endif /* SCALAR_FUNC_H_ */
